==> cramr_ui_lib-0.0.15.tar.gz: lib/widgets/flash_card_stack.dart <==
import 'dart:async';

import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/util/pronoun_decorator.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:provider/provider.dart';

/// Stateful widget that displays a stack of cards that get lifted based on a
/// configurable timer.
class FlashCardStack extends StatefulWidget {
  const FlashCardStack({Key? key}) : super(key: key);

  @override
  State<FlashCardStack> createState() => FlashCardStackState();
}

/// State contains the duration of the Timer and the visibility of the cards on
/// the stack.
class FlashCardStackState extends State<FlashCardStack> {
  int hideIndex = 0;
  List<bool> stackVisibility = [];
  double sliderValue = 2000;

  Timer stackTimer = Timer(const Duration(microseconds: 1), () {});

  @override
  Widget build(BuildContext context) {
    return Column(
      key: UniqueKey(),
      children: [
        Padding(
          key: UniqueKey(),
          padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
          child: SizedBox(
            height: 160,
            child: Stack(
              key: const Key('cardStack'),
              fit: StackFit.loose,
              children: _cardStack(context),
            ),
          ),
        ),
        if (hideIndex > 0)
          Padding(
            key: UniqueKey(),
            padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
            child: FloatingActionButton(
              heroTag: UniqueKey(),
              key: const Key('ResetButton'),
              onPressed: () {
                setState(() {
                  stackVisibility = [true, true, true, true, true, true];
                  hideIndex = 0;
                  stackTimer.cancel();
                });
              },
              child: Icon(
                Icons.refresh,
                key: UniqueKey(),
              ),
            ),
          )
        else
          Padding(
            key: UniqueKey(),
            padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
            child: FloatingActionButton(
              heroTag: UniqueKey(),
              key: const Key('PlayButton'),
              onPressed: () {
                stackTimer.cancel();
                hideIndex = 0;
                stackVisibility = [true, true, true, true, true, true];
                stackTimer = Timer.periodic(
                    Duration(milliseconds: sliderValue.toInt()), (timer) {
                  if (hideIndex < 5) {
                    setState(() {
                      stackVisibility[hideIndex++] = false;
                    });
                  } else {
                    stackTimer.cancel();
                  }
                });
              },
              child: Icon(
                Icons.play_arrow,
                key: UniqueKey(),
              ),
            ),
          ),
        Padding(
          padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
          child: Row(
            key: UniqueKey(),
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Icon(
                FontAwesomeIcons.car,
                key: UniqueKey(),
              ),
              Slider(
                  key: const Key('flashcard_slider'),
                  min: 1000.0,
                  max: 3000.0,
                  divisions: 6,
                  value: sliderValue,
                  onChanged: (double value) {
                    setState(() {
                      sliderValue = value;
                    });
                  }),
              Icon(
                FontAwesomeIcons.bicycle,
                key: UniqueKey(),
              )
            ],
          ),
        ),
      ],
    );
  }

  List<Widget> _cardStack(BuildContext context) {
    List<Widget> _result = [];

    for (int i = 0; i < _numberOfCards(context); i++) {
      stackVisibility.add(true);
    }

    for (int i = _numberOfCards(context) - 1; i >= 0; i--) {
      if (stackVisibility[i]) {
        _result.add(_card(context, i));
      }
    }

    return _result;
  }

  List<StackFit> _stackFitList(BuildContext context) {
    List<StackFit> result = [];
    for (int i = 0; i < _numberOfCards(context); i++) {
      result.add(StackFit.loose);
    }
    return result;
  }

  int _numberOfCards(BuildContext context) {
    return Provider.of<VerbTestModel>(context, listen: false).items.length;
  }

  Widget _card(BuildContext context, int person) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return Card(
        elevation: 10.0,
        margin: const EdgeInsets.fromLTRB(10, 10, 10, 10),
        child: ListTile(
          title: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Expanded(
                child: Padding(
                  padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                  child: Text(
                    PronounDecorator.decoratedPronoun(
                        "fr",
                        testModel.pronouns[person],
                        testModel.verb.indicative[person]),
                    style: const TextStyle(
                      color: Colors.blue,
                      fontSize: 25,
                    ),
                    overflow: TextOverflow.ellipsis,
                  ),
                ),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Text(testModel.verb.indicative[person],
                    style: const TextStyle(
                      color: Colors.green,
                      fontSize: 25,
                    )),
              ),
            ],
          ),
        ),
      );
    });
  }
}

==> cramr_ui_lib-0.0.17.tar.gz: lib/widgets/flash_card_stack.dart <==
import 'dart:async';

import 'package:cramr_ui_lib/util/pronoun_decorator.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

/// Stateful widget that displays a stack of cards that get lifted based on a
/// configurable timer.
class FlashCardStack extends StatefulWidget {
  const FlashCardStack(
      {Key? key,
      required this.expectedIndicative,
      required this.expectedPronouns,
      required this.numberOfCards})
      : super(key: key);

  final List<String> expectedIndicative;
  final List<String> expectedPronouns;
  final int numberOfCards;

  @override
  State<FlashCardStack> createState() => FlashCardStackState();
}

/// State contains the duration of the Timer and the visibility of the cards on
/// the stack.
class FlashCardStackState extends State<FlashCardStack> {
  int hideIndex = 0;
  List<bool> stackVisibility = [];
  double sliderValue = 2000;

  Timer stackTimer = Timer(const Duration(microseconds: 1), () {});

  @override
  Widget build(BuildContext context) {
    return Column(
      key: UniqueKey(),
      children: [
        Padding(
          key: UniqueKey(),
          padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
          child: SizedBox(
            height: 160,
            child: Stack(
              key: const Key('cardStack'),
              fit: StackFit.loose,
              children: _cardStack(context),
            ),
          ),
        ),
        if (hideIndex > 0)
          Padding(
            key: UniqueKey(),
            padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
            child: FloatingActionButton(
              heroTag: UniqueKey(),
              key: const Key('ResetButton'),
              onPressed: () {
                setState(() {
                  stackVisibility = [true, true, true, true, true, true];
                  hideIndex = 0;
                  stackTimer.cancel();
                });
              },
              child: Icon(
                Icons.refresh,
                key: UniqueKey(),
              ),
            ),
          )
        else
          Padding(
            key: UniqueKey(),
            padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
            child: FloatingActionButton(
              heroTag: UniqueKey(),
              key: const Key('PlayButton'),
              onPressed: () {
                stackTimer.cancel();
                hideIndex = 0;
                stackVisibility = [true, true, true, true, true, true];
                stackTimer = Timer.periodic(
                    Duration(milliseconds: sliderValue.toInt()), (timer) {
                  if (hideIndex < 5) {
                    setState(() {
                      stackVisibility[hideIndex++] = false;
                    });
                  } else {
                    stackTimer.cancel();
                  }
                });
              },
              child: Icon(
                Icons.play_arrow,
                key: UniqueKey(),
              ),
            ),
          ),
        Padding(
          padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
          child: Row(
            key: UniqueKey(),
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Icon(
                FontAwesomeIcons.car,
                key: UniqueKey(),
              ),
              Slider(
                  key: const Key('flashcard_slider'),
                  min: 1000.0,
                  max: 3000.0,
                  divisions: 6,
                  value: sliderValue,
                  onChanged: (double value) {
                    setState(() {
                      sliderValue = value;
                    });
                  }),
              Icon(
                FontAwesomeIcons.bicycle,
                key: UniqueKey(),
              )
            ],
          ),
        ),
      ],
    );
  }

  List<Widget> _cardStack(BuildContext context) {
    List<Widget> _result = [];

    for (int i = 0; i < widget.numberOfCards; i++) {
      stackVisibility.add(true);
    }

    for (int i = widget.numberOfCards - 1; i >= 0; i--) {
      if (stackVisibility[i]) {
        _result.add(_card(
            context, widget.expectedPronouns[i], widget.expectedIndicative[i]));
      }
    }

    return _result;
  }

  Widget _card(
      BuildContext context, String fullPronoun, String expectedIndicative) {
    return Card(
      elevation: 10.0,
      margin: const EdgeInsets.fromLTRB(10, 10, 10, 10),
      child: ListTile(
        title: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Expanded(
              child: Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Text(
                  PronounDecorator.decoratedPronoun(
                      "fr", fullPronoun, expectedIndicative),
                  style: const TextStyle(
                    color: Colors.blue,
                    fontSize: 25,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
              child: Text(expectedIndicative,
                  style: const TextStyle(
                    color: Colors.green,
                    fontSize: 25,
                  )),
            ),
          ],
        ),
      ),
    );
  }
}
